function varargout = statusbar(varargin)
% STATUSBAR M-file for statusbar.fig
%      STATUSBAR, by itself, creates a new STATUSBAR or raises the existing
%      singleton*.
%
%      H = STATUSBAR returns the handle to a new STATUSBAR or the handle to
%      the existing singleton*.
%
%      STATUSBAR('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in STATUSBAR.M with the given input arguments.
%
%      STATUSBAR('Property','Value',...) creates a new STATUSBAR or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before statusbar_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to statusbar_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help statusbar

% Last Modified by GUIDE v2.5 12-May-2004 07:39:31

% Begin initialization code - DO NOT EDIT

% Demo created by Roy Schestowitz

gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @statusbar_OpeningFcn, ...
                   'gui_OutputFcn',  @statusbar_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before statusbar is made visible.
function statusbar_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to statusbar (see VARARGIN)

% Choose default command line output for statusbar
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes statusbar wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = statusbar_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes during object creation, after setting all properties.
function edit1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end



function edit1_Callback(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1 as text
%        str2double(get(hObject,'String')) returns contents of edit1 as a double


function pushbutton1_Callback(hObject, eventdata, handles) 

message = [['Welcome to status bar demo                         '];
    ['                                                   '];
    ['Press <clear> to clear the status bar              '];
    ['Press <append> to see how text is appended         '];
    ['to the status bar                                  ']];

% set up a preliminary message to be sent to the status bar. please note
% that the message (matrix) must be rectangular.

set(handles.text2, 'String', message);



function pushbutton2_Callback(hObject, eventdata, handles) 

message = [''];


% set up a preliminary message to be sent to the status bar. please note
% that the message (matrix) must be rectangular.

set(handles.text2, 'String', message);


function pushbutton3_Callback(hObject, eventdata, handles) 

status = get(handles.text2, 'String');
status = [[status];['New line                                           ']];
set(handles.text2, 'String', status);
